@@ -1,22 +1,21 @@
 package GNUpod::FooBar;
-#  Copyright (C) 2002-2005 Adrian Ulrich <pab at blinkenlights.ch>
+#  Copyright (C) 2002-2007 Adrian Ulrich <pab at blinkenlights.ch>
 #  Part of the gnupod-tools collection
 #
 #  URL: http://www.gnu.org/software/gnupod/
 #
-#    This program is free software; you can redistribute it and/or modify
+#    GNUpod is free software; you can redistribute it and/or modify
 #    it under the terms of the GNU General Public License as published by
-#    the Free Software Foundation; either version 2 of the License, or
+#    the Free Software Foundation; either version 3 of the License, or
 #    (at your option) any later version.
 #
-#    This program is distributed in the hope that it will be useful,
+#    GNUpod is distributed in the hope that it will be useful,
 #    but WITHOUT ANY WARRANTY; without even the implied warranty of
 #    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 #    GNU General Public License for more details.
 #
 #    You should have received a copy of the GNU General Public License
-#    along with this program; if not, write to the Free Software
-#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+#    along with this program.  If not, see <http://www.gnu.org/licenses/>.#
 #
 # iTunes and iPod are trademarks of Apple
 #
@@ -25,6 +24,10 @@ package GNUpod::FooBar;
 use strict;
 use Digest::MD5;
 use File::Glob ':glob';
+use GNUpod::iTunesDB;
+
+use constant MACTIME => 2082844800; #Mac EPOCH offset
+
 
 #####################################################################
 # Get paths / files
@@ -49,16 +52,18 @@ if(-d $opth->{mount}) {
   $rr->{playcounts}     = "$rr->{mountpoint}/iPod_Control/iTunes/Play Counts";
   $rr->{itunesdb_md5}   = "$rr->{etc}/.itunesdb_md5";
   $rr->{onthego_invalid}  = "$rr->{etc}/.onthego_invalid";
+  $rr->{lastfm_queue}   = "$rr->{etc}/lastfmqueue.txt";
   $rr->{onthego}        = "$rr->{mountpoint}/iPod_Control/iTunes/OTGPlaylist*";
   $rr->{status}         = undef;
 
+	$rr->{tzdiff} =         GNUpod::iTunesDB::getTimezone($opth->{mount}."/iPod_Control/Device/Preferences");
   _check_casesensitive($rr->{mountpoint}); #Check if somebody mounted the iPod caseSensitive
       
  #Do an iTunesDB Sync if not disabled and needed
   do_itbsync($rr) if(!$opth->{_no_it_sync} && !$opth->{_no_sync} && _itb_needs_sync($rr));
  
  #Do an OTG Sync if not disabled and needed
-  do_otgsync($rr) if(!$opth->{_no_otg_sync} && !$opth->{_no_sync} && _otg_needs_sync($rr));
+  do_otgsync($rr) if(!$opth->{_no_otg_sync} && !$opth->{_no_sync} && (_otg_needs_sync($rr) || -e $rr->{lastfm_queue}))
 }
 elsif($opth->{mount}) {
  $rr->{status} = "$opth->{mount} is not a directory";
@@ -75,17 +80,17 @@ sub _check_casesensitive {
  if(open(CSTEST,">$target/csTeSt")) {
    my $inode_a = (stat("$target/csTeSt"))[1]; #Get inode of just-creaded file
    my $inode_b = (stat("$target/CStEsT"))[1]; #Get inode of another file..
+   close(CSTEST) or die "FATAL: Could not close CSTEST FD ($target/csTeST) : $!\n";
    unlink("$target/csTeSt"); #Boom!
   
    if($inode_a != $inode_b) { #Whops, different inodes? -> case sensitive fs
      #Nerv the user
-     warn "warning: $target seems to be mounted *CASE SENSITIVE*\n";
-     warn "         Mounting VFAT/HFS+ like this is a VERY BAD(tm) idea,\n";
-     warn "         strange things may happen... GNUpod may not work correctly!\n";
+     warn "Warning: $target seems to be mounted *CASE SENSITIVE*\n";
+     warn "         Mounting VFAT like this is a very bad idea!\n";
      warn "         Please mount the Filesystem CASE *IN*SENSITIVE\n";
      warn "         (use 'mount ... -o check=r' for VFAT)\n";
      warn "         [Ignore this message if $target isn't a\n";
-     warn "          VFAT or HFS+ Filesystem ;) ]\n";
+     warn "          VFAT Filesystem (like HFS+) ]\n";
    }
   
  }
@@ -94,6 +99,26 @@ sub _check_casesensitive {
  }
 }
 
+#######################################################################
+# Call mktunes.pl
+sub do_automktunes {
+	my($con) = @_;
+	my $XBIN = "$con->{bindir}/mktunes.pl";
+	if(-x $XBIN) {
+		{
+			local  $ENV{IPOD_MOUNTPOINT} = $con->{mountpoint};
+			if(system("$XBIN > /dev/null")) {
+				die "Unexpected die of $XBIN\n";
+			}
+		}
+	}
+	else {
+		warn "FooBar.pm: Could not execute $XBIN, automktunes SKIPPED!\n";
+		warn "Looks like GNUpod isn't installed correct! did you run 'make install' ?\n";
+	}
+	
+}
+
 #######################################################################
 # Call tunes2pod
 sub do_itbsync {
@@ -115,7 +140,7 @@ if(-x $XBIN) {
 }
 else {
  warn "FooBar.pm: Could not execute $XBIN, autosync SKIPPED!\n";
- warn "Looks like GNUpod isn't installed correct! did you run 'make install?'\n";
+ warn "Looks like GNUpod isn't installed correct! did you run 'make install' ?\n";
 }
 
 }
@@ -366,4 +391,17 @@ sub GetConfig {
   
   return 1;
 }
+
+#############################################
+# Get Unique path
+sub get_u_path {
+ my($prefix, $ext) = @_;
+ my $dst = undef;
+ while($dst = sprintf("%s_%d_%d.$ext",$prefix, int(time()), int(rand(99999)))) {
+  last unless -e $dst;
+ }
+ return $dst;
+}
+
+
 1;
