@@ -1,22 +1,21 @@
 ###__PERLBIN__###
-#  Copyright (C) 2002-2005 Adrian Ulrich <pab at blinkenlights.ch>
+#  Copyright (C) 2002-2007 Adrian Ulrich <pab at blinkenlights.ch>
 #  Part of the gnupod-tools collection
 #
 #  URL: http://www.gnu.org/software/gnupod/
 #
-#    This program is free software; you can redistribute it and/or modify
+#    GNUpod is free software; you can redistribute it and/or modify
 #    it under the terms of the GNU General Public License as published by
-#    the Free Software Foundation; either version 2 of the License, or
+#    the Free Software Foundation; either version 3 of the License, or
 #    (at your option) any later version.
 #
-#    This program is distributed in the hope that it will be useful,
+#    GNUpod is distributed in the hope that it will be useful,
 #    but WITHOUT ANY WARRANTY; without even the implied warranty of
 #    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 #    GNU General Public License for more details.
 #
 #    You should have received a copy of the GNU General Public License
-#    along with this program; if not, write to the Free Software
-#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+#    along with this program.  If not, see <http://www.gnu.org/licenses/>.#
 #
 # iTunes and iPod are trademarks of Apple
 #
@@ -39,9 +38,10 @@ $opts{mount} = $ENV{IPOD_MOUNTPOINT};
 #
 GetOptions(\%opts, "version", "help|h", "mount|m=s", "artist|a=s",
                    "album|l=s", "title|t=s", "id|i=s", "rename=s@",
-                   "playcount|c=s", "podcastrss|R=s", "podcastguid|U=s",
+                   "playcount|c=s", "rating|s=s", "podcastrss|R=s", "podcastguid|U=s",
                    "view=s","genre|g=s", "match-once|o", "delete", "RMME|d");
-GNUpod::FooBar::GetConfig(\%opts, {view=>'s', mount=>'s', 'match-once'=>'b'}, "gnupod_search");
+GNUpod::FooBar::GetConfig(\%opts, {view=>'s', mount=>'s', 'match-once'=>'b', 'automktunes'=>'b'}, "gnupod_search");
+
 
 usage() if $opts{help};
 version() if $opts{version};
@@ -54,7 +54,8 @@ die "You can't use --delete and --rename together\n" if($opts{delete} && $opts{r
 #Build %rename_tags
 foreach(@{$opts{rename}}) {
   my($key,$val) =  split(/=/,$_,2);
-  next unless $key && $val;
+  next unless $key && defined($val);
+  #$key =~ s/^\s*-+//g; # -- is not valid for xml tags!
   next if $key eq "id";#Dont allow something like THIS
   $rename_tags{lc($key)} = $val;
 }
@@ -65,26 +66,22 @@ go();
 ####################################################
 # Worker
 sub go {
- my $con = GNUpod::FooBar::connect(\%opts);
- usage($con->{status}."\n") if $con->{status};
-
- pview(undef,1);
- 
- GNUpod::XMLhelper::doxml($con->{xml}) or usage("Failed to parse $con->{xml}, did you run gnupod_INIT.pl?\n");
- #XML::Parser finished, write new file if we deleted or renamed
- GNUpod::XMLhelper::writexml($con) if $opts{delete} or defined($opts{rename});
-
-
+	my $con = GNUpod::FooBar::connect(\%opts);
+	usage($con->{status}."\n") if $con->{status};
+	
+	pview(undef,1);
+	GNUpod::XMLhelper::doxml($con->{xml}) or usage("Failed to parse $con->{xml}, did you run gnupod_INIT.pl?\n");
+	#XML::Parser finished, write new file if we deleted or renamed
+	GNUpod::XMLhelper::writexml($con,{automktunes=>$opts{automktunes}}) if $opts{delete} or int(@{$opts{rename}});
 }
 
 #############################################
 # Eventhandler for FILE items
 sub newfile {
  my($el) =  @_;
-my $matched;
+my $matched = undef;
                     # 2 = mount + view (both are ALWAYS set)
-my $ntm = keys(%opts)-2-$opts{'match-once'}-$opts{delete}-(defined $opts{rename});
-
+my $ntm = keys(%opts)-2-$opts{'match-once'}-$opts{automktunes}-$opts{delete}-(defined $opts{rename});
 
 foreach my $opx (keys(%opts)) {
 	next if $opx =~ /mount|match-once|delete|view|rename/; #Skip this
@@ -139,7 +136,7 @@ sub newpl {
  # Delete or rename needs to rebuild the XML file
  
  my ($el, $name, $plt) = @_;
- if($plt eq "pl" && ref($el->{add}) eq "HASH") { #Add action
+ if(($plt eq "pl" or $plt eq "pcpl") && ref($el->{add}) eq "HASH") { #Add action
   if(defined($el->{add}->{id}) && int(keys(%{$el->{add}})) == 1) { #Only id
    return unless($keeplist[$el->{add}->{id}]); #ID not on keeplist. drop it
   }
@@ -160,7 +157,7 @@ sub pview {
  
  #Build refs
  my %qh = ();
- $qh{n}{k} = $orf->{songnum};   $qh{n}{w} = 4;  $qh{t}{n} = "SNUM";
+ $qh{n}{k} = $orf->{songnum};   $qh{n}{w} = 4;  $qh{n}{n} = "SNUM";
  $qh{t}{k} = $orf->{title};                     $qh{t}{s} = "TITLE";
  $qh{a}{k} = $orf->{artist};                    $qh{a}{s} = "ARTIST";
  $qh{r}{k} = $orf->{rating};    $qh{r}{w} = 4;  $qh{r}{s} = "RTNG";
@@ -218,6 +215,7 @@ Usage: gnupod_search.pl [-h] [-m directory] File1 File2 ...
    -i, --id=ID             search songs by ID
    -g, --genre=GENRE       search songs by Genre
    -c, --playcount=COUNT   search songs by Playcount
+   -s, --rating=COUNT      search songs by Rating (20 is one star, 40 two, etc.)
    -R, --podcastrss=RSS    search songs by RSS
    -G, --podcastguid=GUID  search songs by GUID
    -o, --match-once        Search doesn't need to match multiple times (eg. -a & -l)
@@ -242,7 +240,7 @@ EOF
 sub version {
 die << "EOF";
 gnupod_search.pl (gnupod) ###__VERSION__###
-Copyright (C) Adrian Ulrich 2002-2004
+Copyright (C) Adrian Ulrich 2002-2005
 
 This is free software; see the source for copying conditions.  There is NO
 warranty; not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
